Module: LesliBabel

Defined in:
lib/lesli_babel/engine.rb,
lib/lesli_babel.rb,
lib/lesli_babel/version.rb,
app/models/lesli_babel/label.rb,
app/models/lesli_babel/bucket.rb,
app/models/lesli_babel/module.rb,
app/models/lesli_babel/dashboard.rb,
app/jobs/lesli_babel/application_job.rb,
app/helpers/lesli_babel/labels_helper.rb,
app/services/lesli_babel/label_service.rb,
app/services/lesli_babel/module_service.rb,
app/models/lesli_babel/application_record.rb,
app/mailers/lesli_babel/application_mailer.rb,
app/services/lesli_babel/translation_service.rb,
app/controllers/lesli_babel/labels_controller.rb,
app/controllers/lesli_babel/buckets_controller.rb,
app/controllers/lesli_babel/modules_controller.rb,
app/controllers/lesli_babel/dashboards_controller.rb,
app/controllers/lesli_babel/application_controller.rb,
app/controllers/lesli_babel/translations_controller.rb

Overview

Lesli

Copyright © 2025, Lesli Technologies, S. A.

This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with this program. If not, see www.gnu.org/licenses/.

Lesli · Ruby on Rails SaaS Development Framework.

Made with ♥ by LesliTech Building a better future, one line of code at a time.

// · ~·~ ~·~ ~·~ ~·~ ~·~ ~·~ ~·~ ~·~ ~·~ // ·

Defined Under Namespace

Modules: LabelsHelper Classes: ApplicationController, ApplicationJob, ApplicationMailer, ApplicationRecord, Bucket, BucketsController, Dashboard, DashboardsController, Engine, Label, LabelService, LabelsController, Module, ModuleService, ModulesController, TranslationService, TranslationsController

Constant Summary collapse

VERSION =
"1.1.0"
BUILD =
"1777771350"